use super::helpers;
use bson::doc;
use log::{trace, warn};
use wccg_models::activity::ActivityType;
use wccg_models::activity::RiderSummary;
use wccg_models::any::Any;
use wread_data_mongodb::crud_repository;
use wread_data_mongodb::mongodb::{error::Error, Database};

const COLLECTION_NAME: &str = "riderSummary";

pub fn get_by_rider_id(rider_id: &String, db: &Database) -> Result<Option<RiderSummary>, Error> {
    crud_repository::find_one(doc! {"riderId": rider_id }, COLLECTION_NAME, &db)
}

pub fn increment_activity_stats(
    rider_id: &String,
    activity_type: &ActivityType,
    distance: f32,
    count: i32,
    commute_distance: f32,
    commute_count: i32,
    db: &Database,
) {
    trace!("increment_activity_totals");
    init_rider_summary(rider_id, db);

    if let Some(update_document) = helpers::get_activity_stats_update_document(
        activity_type,
        distance,
        count,
        commute_distance,
        commute_count,
    ) {
        crud_repository::update_one(
            doc! {"riderId": rider_id},
            update_document,
            None,
            COLLECTION_NAME,
            db,
        )
        .unwrap();
    } else {
        warn!("None from get_activity_stats_update_document");
    }
}

fn init_rider_summary(rider_id: &String, db: &Database) {
    let rider_summary =
        crud_repository::find_one::<Any>(doc! {"riderId": rider_id}, COLLECTION_NAME, db).unwrap();

    if let None = rider_summary {
        let mut empty_rider_summary = RiderSummary::default();
        empty_rider_summary.set_rider_id(rider_id.to_owned());
        crud_repository::add(&empty_rider_summary, COLLECTION_NAME, db).unwrap();
    }
}
